@@ -2,17 +2,17 @@
 #include "fastcpd_test_constants.h"
 #include "testthat.h"
 
-context("negative_log_likelihood_wo_theta Unit Test") {
+context("get_nll_wo_theta Unit Test") {
   test_that("arma(3, 2) is correct for 200 data points") {
     fastcpd::classes::Fastcpd fastcpd_class(
       /* beta */ 0,
-      /* convexity_coef */ 0,
       /* cost */ R_NilValue,
       /* cost_adjustment */ "MBIC",
       /* cost_gradient */ R_NilValue,
       /* cost_hessian */ R_NilValue,
       /* cp_only */ true,
-      /* data */ mat(),
+      /* d */ 0,
+      /* data */ colvec(kARMA32.data(), kARMA32.size()),
       /* epsilon */ 0.0,
       /* family */ "arma",
       /* k */ R_NilValue,
@@ -22,6 +22,8 @@ context("negative_log_likelihood_wo_theta Unit Test") {
       /* order */ colvec({3, 2}),
       /* p */ 0,
       /* p_response */ 0,
+      /* pruning_coef */ 0,
+      /* r_clock */ "",
       /* r_progress */ false,
       /* segment_count */ 0,
       /* trim */ 0,
@@ -31,10 +33,9 @@ context("negative_log_likelihood_wo_theta Unit Test") {
       /* warm_start */ false
     );
 
-    const colvec data(kARMA32.data(), kARMA32.size());
     const fastcpd::classes::CostResult cost_result =
-    fastcpd_class.negative_log_likelihood_wo_theta(
-      data, 0, false, R_NilValue
+    fastcpd_class.get_nll_wo_theta(
+      0, 199, 0, false, R_NilValue
     );
     const colvec par = cost_result.par;
     const double value = cost_result.value;
@@ -54,17 +55,18 @@ context("negative_log_likelihood_wo_theta Unit Test") {
   }
 }
 
-context("negative_log_likelihood_wo_cv Unit Test") {
+context("get_nll_wo_cv Unit Test") {
   test_that("arma(3, 2) is correct for 200 data points") {
+    const colvec data(kARMA32.data(), kARMA32.size());
     fastcpd::classes::Fastcpd fastcpd_class(
       /* beta */ 0,
-      /* convexity_coef */ 0,
       /* cost */ R_NilValue,
       /* cost_adjustment */ "MBIC",
       /* cost_gradient */ R_NilValue,
       /* cost_hessian */ R_NilValue,
       /* cp_only */ true,
-      /* data */ mat(),
+      /* d */ 0,
+      /* data */ data,
       /* epsilon */ 0.0,
       /* family */ "arma",
       /* k */ R_NilValue,
@@ -74,6 +76,8 @@ context("negative_log_likelihood_wo_cv Unit Test") {
       /* order */ colvec({3, 2}),
       /* p */ 0,
       /* p_response */ 0,
+      /* pruning_coef */ 0,
+      /* r_clock */ "",
       /* r_progress */ false,
       /* segment_count */ 0,
       /* trim */ 0,
@@ -83,10 +87,9 @@ context("negative_log_likelihood_wo_cv Unit Test") {
       /* warm_start */ false
     );
 
-    const colvec data(kARMA32.data(), kARMA32.size());
     const colvec theta = 0.1 * ones<colvec>(6);
     const double value =
-      fastcpd_class.negative_log_likelihood_wo_cv(data, theta, 0.0);
+      fastcpd_class.get_nll_wo_cv(0, 199, theta, 0.0);
     const double expected_value = 1363.288;
     expect_true(abs(value -  expected_value) < 0.001);
   }
@@ -96,13 +99,13 @@ context("cost_update_gradient Unit Test") {
   test_that("arma(3, 2) is correct for 200 data points") {
     fastcpd::classes::Fastcpd fastcpd_class(
       /* beta */ 0,
-      /* convexity_coef */ 0,
       /* cost */ R_NilValue,
       /* cost_adjustment */ "MBIC",
       /* cost_gradient */ R_NilValue,
       /* cost_hessian */ R_NilValue,
       /* cp_only */ true,
-      /* data */ mat(),
+      /* d */ 0,
+      /* data */ colvec(kARMA32.data(), kARMA32.size()),
       /* epsilon */ 0.0,
       /* family */ "arma",
       /* k */ R_NilValue,
@@ -112,6 +115,8 @@ context("cost_update_gradient Unit Test") {
       /* order */ colvec({3, 2}),
       /* p */ 0,
       /* p_response */ 0,
+      /* pruning_coef */ 0,
+      /* r_clock */ "",
       /* r_progress */ false,
       /* segment_count */ 0,
       /* trim */ 0,
@@ -121,9 +126,8 @@ context("cost_update_gradient Unit Test") {
       /* warm_start */ false
     );
 
-    const colvec data(kARMA32.data(), kARMA32.size());
     const colvec theta = 0.1 * ones<colvec>(6);
-    const colvec gradient = fastcpd_class.cost_update_gradient(data, theta);
+    const colvec gradient = fastcpd_class.cost_update_gradient(0, 199, theta);
     const colvec expected_gradient =
       {4.401258, 6.600128, -7.591818, 4.151778, 7.503752, -2.806806};
     expect_true(norm(gradient - expected_gradient, "fro") < 1e-6);
@@ -134,13 +138,13 @@ context("cost_update_hessian Unit Test") {
   test_that("binomal is correct for a two dimensional data") {
     fastcpd::classes::Fastcpd fastcpd_class(
       /* beta */ 0,
-      /* convexity_coef */ 0,
       /* cost */ R_NilValue,
       /* cost_adjustment */ "MBIC",
       /* cost_gradient */ R_NilValue,
       /* cost_hessian */ R_NilValue,
       /* cp_only */ true,
-      /* data */ mat(),
+      /* d */ 0,
+      /* data */ {{1, 1, 0.2}},
       /* epsilon */ 0.0,
       /* family */ "binomial",
       /* k */ R_NilValue,
@@ -150,6 +154,8 @@ context("cost_update_hessian Unit Test") {
       /* order */ colvec(),
       /* p */ 0,
       /* p_response */ 0,
+      /* pruning_coef */ 0,
+      /* r_clock */ "",
       /* r_progress */ false,
       /* segment_count */ 0,
       /* trim */ 0,
@@ -159,9 +165,8 @@ context("cost_update_hessian Unit Test") {
       /* warm_start */ false
     );
 
-    const mat data = {{1, 1, 0.2}};
     const colvec theta = {-0.5, 0.3};
-    const mat hessian = fastcpd_class.cost_update_hessian(data, theta);
+    const mat hessian = fastcpd_class.cost_update_hessian(0, 0, theta);
     const mat expected_hessian =
         {{0.238'28, 0.047'656}, {0.047'656, 0.009'531'2}};
     expect_true(norm(hessian - expected_hessian, "fro") < 0.000'001);
@@ -170,13 +175,13 @@ context("cost_update_hessian Unit Test") {
   test_that("poisson is correct for a two dimensional data") {
     fastcpd::classes::Fastcpd fastcpd_class(
       /* beta */ 0,
-      /* convexity_coef */ 0,
       /* cost */ R_NilValue,
       /* cost_adjustment */ "MBIC",
       /* cost_gradient */ R_NilValue,
       /* cost_hessian */ R_NilValue,
       /* cp_only */ true,
-      /* data */ mat(),
+      /* d */ 0,
+      /* data */ {{4, 1, 0.2}},
       /* epsilon */ 0.0,
       /* family */ "poisson",
       /* k */ R_NilValue,
@@ -186,6 +191,8 @@ context("cost_update_hessian Unit Test") {
       /* order */ colvec(),
       /* p */ 0,
       /* p_response */ 0,
+      /* pruning_coef */ 0,
+      /* r_clock */ "",
       /* r_progress */ false,
       /* segment_count */ 0,
       /* trim */ 0,
@@ -195,9 +202,8 @@ context("cost_update_hessian Unit Test") {
       /* warm_start */ false
     );
 
-    const mat data = {{4, 1, 0.2}};
     const colvec theta = {-0.5, 0.3};
-    const mat hessian = fastcpd_class.cost_update_hessian(data, theta);
+    const mat hessian = fastcpd_class.cost_update_hessian(0, 0, theta);
     const mat expected_hessian =
         {{0.644'036'4, 0.128'807}, {0.128'807, 0.025'761'6}};
     expect_true(norm(hessian - expected_hessian, "fro") < 0.000'001);
@@ -206,13 +212,13 @@ context("cost_update_hessian Unit Test") {
   test_that("arma(3, 2) is correct for 200 data points") {
     fastcpd::classes::Fastcpd fastcpd_class(
       /* beta */ 0,
-      /* convexity_coef */ 0,
       /* cost */ R_NilValue,
       /* cost_adjustment */ "MBIC",
       /* cost_gradient */ R_NilValue,
       /* cost_hessian */ R_NilValue,
       /* cp_only */ true,
-      /* data */ mat(),
+      /* d */ 0,
+      /* data */ colvec(kARMA32.data(), kARMA32.size()),
       /* epsilon */ 0.0,
       /* family */ "arma",
       /* k */ R_NilValue,
@@ -222,6 +228,8 @@ context("cost_update_hessian Unit Test") {
       /* order */ colvec({3, 2}),
       /* p */ 0,
       /* p_response */ 0,
+      /* pruning_coef */ 0,
+      /* r_clock */ "",
       /* r_progress */ false,
       /* segment_count */ 0,
       /* trim */ 0,
@@ -231,9 +239,8 @@ context("cost_update_hessian Unit Test") {
       /* warm_start */ false
     );
 
-    const colvec data(kARMA32.data(), kARMA32.size());
     const colvec theta = 0.1 * ones<colvec>(6);
-    const mat hessian = fastcpd_class.cost_update_hessian(data, theta);
+    const mat hessian = fastcpd_class.cost_update_hessian(0, 199, theta);
     const mat expected_hessian = {
       { 12.406525,  18.60483, -21.40027,   4.743794,  28.98263, -44.01258},
       { 18.604831,  27.89981, -32.09185,  25.380851,  27.48253, -66.00128},
@@ -250,12 +257,12 @@ context("update_theta_sum Unit Test") {
   test_that("update performs normally") {
     fastcpd::classes::Fastcpd fastcpd_class(
       /* beta */ 0,
-      /* convexity_coef */ 0,
       /* cost */ R_NilValue,
       /* cost_adjustment */ "MBIC",
       /* cost_gradient */ R_NilValue,
       /* cost_hessian */ R_NilValue,
       /* cp_only */ true,
+      /* d */ 0,
       /* data */ mat(),
       /* epsilon */ 0.0,
       /* family */ "gaussian",
@@ -266,6 +273,8 @@ context("update_theta_sum Unit Test") {
       /* order */ colvec(),
       /* p */ 3,
       /* p_response */ 0,
+      /* pruning_coef */ 0,
+      /* r_clock */ "",
       /* r_progress */ false,
       /* segment_count */ 0,
       /* trim */ 0,
