@@ -4,6 +4,6 @@ testthat::test_that(
     testthat::skip_if_not_installed("mvtnorm")
 
     source("examples/fastcpd_1.R")
-    testthat::expect_equal(result@cp_set, c(99, 200))
+    testthat::expect_equal(result_mlm@cp_set, 125)
   }
 )
